import { BasicColumn, FormSchema } from '@/components/Table';
import { DescItem } from '@/components/Description';

export const applyColumns: BasicColumn[] = [
  {
    title: 'API名称',
    dataIndex: 'name',
    width: 120,
  },
  {
    title: '编目',
    dataIndex: 'cataloging',
    width: 120,
  },
  {
    title: '权属机构',
    dataIndex: 'workGroup',
    width: 120,
  },
  {
    title: '发布者',
    dataIndex: 'publisher',
    width: 120,
  },
  {
    title: '发布时间',
    dataIndex: 'publishTime',
    width: 120,
  },
  {
    title: '我的权限',
    dataIndex: 'permission',
    width: 120,
  },
];
export const applyFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: '',
    component: 'Input',
    componentProps: {
      placeholder: '搜索资源名称',
    },
    colProps: { span: 4 },
  },
  {
    field: 'workGroup',
    label: ' ',
    component: 'Select',
    componentProps: {
      placeholder: '权属机构',
      options: [
        { label: '测试功能部', value: '11' },
        { label: '开发部', value: '12' },
        { label: '市场部', value: '13' },
        { label: '财务部', value: '14' },
      ],
    },
    colProps: { span: 4 },
  },
  {
    field: 'permission',
    label: '',
    component: 'Select',
    componentProps: {
      placeholder: '我的权限',
      options: [
        { label: '下载', value: '1' },
        { label: '推送', value: '2' },
      ],
    },
    colProps: { span: 4 },
  },
];
export const ManagePropertySchema: DescItem[] = [
  {
    field: 'resourceCataloging',
    label: '资源编目',
  },
  {
    field: 'ownerInstitution',
    label: '权属机构',
  },
  {
    field: 'label',
    label: 'Label',
  },
];

export const permissionsInfo: DescItem[] = [
  {
    field: 'permissions',
    label: '权限',
  },
];
export const BasicInfoSchema: DescItem[] = [
  {
    field: 'creator',
    label: '创建者',
  },
  {
    field: 'createDate',
    label: '创建时间',
  },
  {
    field: 'updateFrequency',
    label: '更新频率',
  },
  {
    field: 'securityClassification',
    label: '安全分级',
  },
  {
    field: 'sourceDataTable',
    label: '源数据表',
  },
  {
    field: 'sourceTableSize',
    label: '源表大小',
  },
  {
    field: 'releaseStatus',
    label: '发布状态',
  },
  {
    field: 'releaser',
    label: '发布者',
  },
  {
    field: 'releaseDate',
    label: '发布时间',
  },
  {
    field: 'describe',
    label: '描述',
  },
];
export const infoDataColumns: BasicColumn[] = [
  {
    title: 'id(主键)',
    type: 'bigint unsigned',
    dataIndex: 'id',
    width: 120,
  },
  {
    title: 'uuid(编目用UUID)',
    type: 'varchar(32)',
    dataIndex: 'uuid',
    width: 120,
  },
  {
    title: 'assets_name(资产名称)',
    type: 'varchar(255)',
    dataIndex: 'assetsName',
    width: 120,
  },
  {
    title: 'directory_uuid(资产编目uuid)',
    type: 'varchar(32)',
    dataIndex: 'directoryUuid',
    width: 120,
  },
  {
    title: 'business_code(业务编码)',
    type: 'varchar(32)',
    dataIndex: 'businessCode',
    width: 120,
  },
  {
    title: 'category',
    type: 'varchar(32)',
    dataIndex: 'category',
    width: 120,
  },
  {
    title: 'source(资产来源，枚举值)',
    type: 'varchar(32)',
    dataIndex: 'source',
    width: 120,
  },
  {
    title: 'assets_type(资产类型)',
    type: 'varchar(32)',
    dataIndex: 'assetsType',
    width: 120,
  },
  {
    title: 'assets_status(资产状态)',
    type: 'varchar(32)',
    dataIndex: 'assetsStatus',
    width: 120,
  },
];
export const infoColumns: BasicColumn[] = [
  {
    title: '表名',
    dataIndex: 'tableName',
    width: 120,
  },
  {
    title: '列名',
    dataIndex: 'columnsName',
    width: 120,
  },
  {
    title: '中文名',
    dataIndex: 'CNname',
    width: 120,
    // edit: true,
  },
  {
    title: '字段描述',
    dataIndex: 'remark',
    width: 120,
  },
  {
    title: '字段类型',
    dataIndex: 'type',
    width: 120,
  },
  {
    title: '可空',
    dataIndex: 'isNull',
    width: 120,
  },
  {
    title: '问题数据固定列',
    dataIndex: 'isFixation',
    width: 120,
  },
];
export const SearchFormSchema: FormSchema[] = [
  {
    field: 'columnsName',
    label: '',
    componentProps: {
      placeholder: '搜索字段',
    },
    component: 'Input',
    colProps: { span: 5 },
  },
];
export const reviewColumns: BasicColumn[] = [
  {
    title: '操作时间',
    dataIndex: 'infoTime',
    width: 120,
  },
  {
    title: '操作类型',
    dataIndex: 'operationType',
    width: 120,
  },
  {
    title: '目标端',
    dataIndex: 'target',
    width: 120,
  },
  {
    title: '数据范围',
    dataIndex: 'mechanism',
    width: 120,
  },
  {
    title: '操作状态',
    dataIndex: 'status',
    width: 120,
  },
];
export const infoBasicSchema: FormSchema[] = [
  {
    field: 'operator',
    label: ' ',
    labelWidth: 20,
    componentProps: {
      placeholder: '操作人',
    },
    component: 'Input',
    colProps: { span: 4 },
  },
  {
    field: 'mechanism',
    label: ' ',
    labelWidth: 20,
    componentProps: {
      placeholder: '操作人所属机构',
      options: [
        { label: '机构1', value: '1' },
        { label: '机构2', value: '2' },
        { label: '机构3', value: '3' },
        { label: '机构4', value: '4' },
      ],
    },
    component: 'Input',
    colProps: { span: 4 },
  },
  {
    field: 'operationType',
    label: ' ',
    labelWidth: 20,
    componentProps: {
      placeholder: '操作类型',
      options: [
        { label: '下载', value: '1' },
        { label: '推送', value: '2' },
        { label: '共享到智能平台', value: '3' },
        { label: 'API调用', value: '4' },
      ],
    },
    component: 'Select',
    colProps: { span: 4 },
  },
  {
    field: 'status',
    label: ' ',
    labelWidth: 20,
    componentProps: {
      placeholder: '状态',
      options: [
        { label: '成功', value: '1' },
        { label: '失败', value: '0' },
      ],
    },
    component: 'Select',
    colProps: { span: 4 },
  },
  {
    field: 'infoTime',
    label: ' ',
    labelWidth: 20,
    component: 'RangePicker',
    colProps: { span: 4 },
  },
];
export const associationRulesColumns: BasicColumn[] = [
  {
    title: '申请人',
    dataIndex: 'applicant',
    width: 120,
  },
  {
    title: '申请人所属机构',
    dataIndex: 'appInstitution',
    width: 120,
  },
  {
    title: '申请时间',
    dataIndex: 'applicationTime',
    width: 120,
    // edit: true,
  },
  {
    title: '申请类型',
    dataIndex: 'applicationType',
    width: 120,
  },
  {
    title: '申请标题',
    dataIndex: 'titleApplication',
    width: 120,
  },
  {
    title: '状态',
    dataIndex: 'status',
    width: 120,
  },
];
export const associationSearchFormSchema: FormSchema[] = [
  {
    field: 'appInstitution',
    label: ' ',
    labelWidth: 20,
    componentProps: {
      placeholder: '申请人所属机构',
      options: [
        { label: '机构1', value: '1' },
        { label: '机构2', value: '2' },
        { label: '机构3', value: '3' },
      ],
    },
    component: 'Select',
    colProps: { span: 4 },
  },
  {
    field: 'applicationType',
    label: ' ',
    labelWidth: 20,
    componentProps: {
      placeholder: '申请类型',
      options: [
        { label: '推送', value: '1' },
        { label: '下载', value: '2' },
      ],
    },
    component: 'Select',
    colProps: { span: 4 },
  },
  {
    field: 'status',
    label: ' ',
    labelWidth: 20,
    componentProps: {
      placeholder: '状态',
      options: [
        { label: '待审核', value: '1' },
        { label: '已通过', value: '2' },
        { label: '已驳回', value: '3' },
      ],
    },
    component: 'Select',
    colProps: { span: 4 },
  },
];
export const associationRulesInfoColumns: BasicColumn[] = [
  {
    title: '权限类型',
    dataIndex: 'applicationType',
    width: 120,
  },
  {
    title: '目标端',
    dataIndex: 'target',
    width: 120,
  },
  {
    title: '用户名',
    dataIndex: 'name',
    width: 120,
  },
  {
    title: '对应申请',
    dataIndex: 'titleApplication',
    width: 120,
  },
  {
    title: '数据范围',
    dataIndex: 'appInstitution',
    width: 120,
  },
  {
    title: '权限状态',
    dataIndex: 'status',
    width: 120,
  },
  {
    title: '无效原因',
    dataIndex: 'invalidReason',
    width: 120,
  },
];
export const associationSearchInfoFormSchema: FormSchema[] = [
  {
    field: 'nameAndTitle',
    label: ' ',
    labelWidth: 20,
    componentProps: {
      placeholder: '搜索用户名或申请标题',
    },
    component: 'Input',
    colProps: { span: 4 },
  },
  {
    field: 'applicationType',
    label: ' ',
    labelWidth: 20,
    componentProps: {
      placeholder: '权限类型',
      options: [
        { label: '推送', value: '1' },
        { label: '下载', value: '2' },
      ],
    },
    component: 'Select',
    colProps: { span: 4 },
  },
  {
    field: 'status',
    label: ' ',
    labelWidth: 20,
    componentProps: {
      placeholder: '权限状态',
      options: [
        { label: '待审核', value: '1' },
        { label: '已通过', value: '2' },
        { label: '已驳回', value: '3' },
      ],
    },
    component: 'Select',
    colProps: { span: 4 },
  },
];
export const pushTypeColumns: BasicColumn[] = [
  {
    title: '目标端',
    dataIndex: 'target',
    width: 120,
  },
  {
    title: '推送类型',
    dataIndex: 'pushType',
    width: 120,
  },
];
export const dataRangeSchema: DescItem[] = [
  {
    field: 'custom',
    label: '自定义条件',
  },
  {
    field: 'institutions',
    label: '机构',
  },
  {
    field: 'time',
    label: '时间',
  },
];
export const dataRangeColumns: BasicColumn[] = [
  {
    title: '调度时间',
    dataIndex: 'time',
    width: 140,
  },
  {
    title: '执行时间',
    dataIndex: 'executeTime',
    width: 140,
  },
  {
    title: '执行时长',
    dataIndex: 'duration',
    width: 120,
  },
  {
    title: '执行模式',
    dataIndex: 'mode',
    width: 120,
  },
  {
    title: '状态',
    dataIndex: 'status',
    width: 120,
  },
];
export const downloadColumns: BasicColumn[] = [
  {
    title: '申请名称',
    dataIndex: 'name',
    width: 120,
  },
  {
    title: '数据范围',
    dataIndex: 'dataRange',
    width: 120,
  },
  {
    title: '申请时间',
    dataIndex: 'time',
    width: 120,
  },
];
